<?php
// Connect to the database.
require_once 'library/useful-stuff.php';
// Show no errors so far.
$errorMessage = '';
// Get the household name.
$householdName = getParamFromGet('household_name');
$errorMessage = checkHouseholdName($householdName);
// Lookup the doggos.
if ($errorMessage == '') {
    $sql = "
        SELECT doggos.name as doggo_name
        FROM households, doggos
        WHERE households.name = :household_name
           AND households.household_id = doggos.household
        ORDER BY doggos.name;
    ";
    /** @var PDO $dbConnection */
    $stmnt = $dbConnection->prepare($sql);
    $isWorked = $stmnt->execute(['household_name' => $householdName]);
    if (!$isWorked) {
        $errorMessage = 'Something went wrong with the look up.';
    }
    if ($errorMessage == '') {
        // Found any records?
        if ($stmnt->rowCount() == 0) {
            $errorMessage = "Sorry, couldn't find doggos in the $householdName household.";
        } else {
            $rows = $stmnt->fetchAll();
        }
    }
}
?><!doctype html>
<html lang="en">
    <head>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
        <title>Doggos in household</title>
        <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.1.1/css/bootstrap.min.css">
        <script src="https://code.jquery.com/jquery-3.3.1.min.js"></script>
        <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.0/umd/popper.min.js"></script>
        <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.1.1/js/bootstrap.min.js"></script>
        <link rel="stylesheet" href="library/drawing.css">
    </head>
    <body>
        <div class="container">
            <div class="col">
                <h1>Doggos in household</h1>
                <?php
                if ($errorMessage != '') {
                    print "<p class='alert-danger text-danger m-2 p-2'>$errorMessage</p>";
                }
                else {
                    // There are doggos to show.
                    print "<p>Doggos in the $householdName household.</p>\n";
                    print "<ul>\n";
                    foreach ($rows as $row) {
                        $doggoName = $row['doggo_name'];
                        print "<li>$doggoName</li>\n";
                    }
                    print "</ul>\n";
                }
                ?>
            </div>
        </div>
    </body>
</html>